@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Blio;
 
-# ABSTRACT: script to run Blio
+# ABSTRACT: Blio - domm's blogging "engine"
 # PODNAME: blio.pl
 
 Blio->new_with_options->run;
@@ -12,13 +12,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-blio.pl - script to run Blio
+blio.pl - Blio - domm's blogging "engine"
 
 =head1 VERSION
 
-version 2.002
+version 2.003
 
 =head1 SYNOPSIS
 
@@ -81,7 +83,7 @@ The publication date of this post. Has to be parsable by C<DateTime::Format::ISO
 
 =head4 language
 
-The language of this post.
+The language of this post. See CONFIGURATION.
 
 =head4 converter
 
@@ -113,7 +115,7 @@ Thumbnail size
 
 =head3 Content
 
-The content can be generated the common formatting languages supported by C<Markup::Unified>, or HTML
+The content can be generated using the common formatting languages supported by C<Markup::Unified>, or HTML
 
 =head3 Example
 
@@ -128,6 +130,47 @@ The content can be generated the common formatting languages supported by C<Mark
     
     There's a small tourist info where you can get soup.
 
+=head1 INSTALLATION
+
+C<Blio> runs on L<Perl|http://perl.org> application, and thus requires a rencent Perl (>= 5.10). It also reuses a lot of code from L<CPAN|http://cpan.org>.
+
+=head2 From CPAN
+
+The easiest way to install the current stable version of C<Blio> is via L<CPAN|http://cpan.org> and C<cpanminus>
+
+  ~$ cpanm Blio
+  Fetching http://www.cpan.org/authors/id/D/DO/DOMM/Blio-2.002.tar.gz ... OK
+  Configuring Blio-2.002 ... OK
+  ... # installing dependencies
+  Building and testing Blio-2.002 ... OK
+  Successfully installed Blio-2.002
+
+If you don't have C<cpanminus> installed yet, L<install it right now|http://search.cpan.org/dist/App-cpanminus/lib/App/cpanminus.pm#INSTALLATION>:
+
+  ~$ curl -L http://cpanmin.us | perl - --sudo App::cpanminus
+
+=head2 From a tarball or git checkout
+
+To install C<Blio> from a tarball or a git checkout, you will need L<Dist::Zilla|https://metacpan.org/module/Dist::Zilla> and some C<Dist::Zilla>-plugins
+
+  ~/perl/Blio$ cpanm Dist::Zilla
+  ~/perl/Blio$ dzil authordeps | cpanm
+
+Now you can build a C<Blio> distributrion
+
+  ~/perl/Blio$ dzil build
+
+And finally you can install C<Blio> via C<dzil>:
+
+  ~/perl/Blio$ dzil install
+
+Or change into the build directory (F<Blio-$VERSION>) and do the old install dance:
+
+  ~/perl/Blio/Blio-2.002$ perl Build.PL
+  ~/perl/Blio/Blio-2.002$ ./Build
+  ~/perl/Blio/Blio-2.002$ ./Build test
+  ~/perl/Blio/Blio-2.002$ ./Build install  # might require sudo
+
 =head1 CONFIGURATION
 
 C<Blio> can be configured via a combination of command line options and a config file.
@@ -154,7 +197,10 @@ The directory where the rendered HTML files are stored. This directory should be
 
 The directory containing the templates used to render your content. Default 'template'.
 
-Please note that some very simple (and very ugly) default templates are provided by Blio. These are installed via File::ShareDir.
+Please note that some very simple (and very ugly) default templates
+are provided by Blio. They come in the share/templates directory of
+the distribution and are installed along the module via
+File::ShareDir.
 
 =head3 name
 
@@ -166,7 +212,7 @@ The URL of your blog (needed to generate a proper RSS feed)
 
 =head3 site_author
 
-Your name  (needed to generate a proper RSS feed)
+Your name (needed to generate a proper RSS feed)
 
 =head3 tags
 
@@ -186,11 +232,11 @@ Do not producde regular output
 
 =head2 Per-Node config
 
-Per-Node config can be specified per node, or falls back to a global value speciefied via command line option or in the config file.
+Per-Node config can be specified per node, or falls back to a global value specified via command line option or in the config file.
 
 =head3 language
 
-The default language of your content. You can set other languages per node.
+The default language of your content. You can set other languages per node. Default "en".
 
 =head3 converter
 
@@ -198,10 +244,48 @@ The default text2html converter. You can choose other converters per node. Curre
 
 =head3 thumbnail
 
-The width (in pixel) of thumbnails that are generated by Blio / Imager.
+The width (in pixel) of thumbnails that are generated by Blio / Imager. Default "300".
 
 =head1 USAGE
 
+=head2 DIRECTORY LAYOUT
+
+=head2 NODE SYNTAX
+
+=head1 TEMPLATES
+
+=head2 Methods available in templates
+
+=head3 $blio->..
+
+=head3 $node->..
+
+=head1 ARTICLES & PRESENTATIONS
+
+=over 4
+
+=item 2013.05.03
+
+L<Talk at Linuxwochen 2013 Wien|http://domm.plix.at/talks/blio.html> (in german)
+
+=item 2013.03.28
+
+L<Building a static blog using Blio and Github|http://perl5maven.com/building-a-static-blog-using-blio-and-github>
+
+=item 2013.01.20
+
+L<Blio updates|http://domm.plix.at/perl/2013_01_blio_updates.html>
+
+=item 2012.09.11
+
+L<Some new Blio features|http://domm.plix.at/perl/2012_09_11_some_new_blio_features.html>
+
+=item 2012.08.09
+
+L<Blio - my blogging "engine"|http://domm.plix.at/perl/2012_08_09_blio_my_blogging_engine.html>
+
+=back
+
 =head1 AUTHOR
 
 Thomas Klausner <domm@cpan.org>
